@@ -47,6 +47,7 @@ typedef struct _GMimeGpgContextClass GMimeGpgContextClass;
  **/
 struct _GMimeGpgContext {
 	GMimeCipherContext parent_object;
+	gboolean auto_key_retrieve;
 	gboolean always_trust;
 	char *path;
 };
@@ -60,7 +61,10 @@ struct _GMimeGpgContextClass {
 GType g_mime_gpg_context_get_type (void);
 
 
-GMimeCipherContext *g_mime_gpg_context_new (GMimeSession *session, const char *path);
+GMimeCipherContext *g_mime_gpg_context_new (GMimePasswordRequestFunc request_passwd, const char *path);
+
+gboolean g_mime_gpg_context_get_auto_key_retrieve (GMimeGpgContext *ctx);
+void g_mime_gpg_context_set_auto_key_retrieve (GMimeGpgContext *ctx, gboolean auto_key_retrieve);
 
 gboolean g_mime_gpg_context_get_always_trust (GMimeGpgContext *ctx);
 void g_mime_gpg_context_set_always_trust (GMimeGpgContext *ctx, gboolean always_trust);
