@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -153,20 +153,12 @@ message_partial_set_header (GMimeObject *object, const char *header, const char
 static const char *
 message_partial_get_header (GMimeObject *object, const char *header)
 {
-	/* RFC 1864 states that you cannot set a Content-MD5 on a message part */
-	if (!g_ascii_strcasecmp ("Content-MD5", header))
-		return NULL;
-	
 	return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
 }
 
 static gboolean
 message_partial_remove_header (GMimeObject *object, const char *header)
 {
-	/* RFC 1864 states that you cannot set a Content-MD5 on a message part */
-	if (!g_ascii_strcasecmp ("Content-MD5", header))
-		return FALSE;
-	
 	return GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
@@ -320,17 +312,17 @@ g_mime_message_partial_reconstruct_message (GMimeMessagePartial **partials, size
 	const char *id;
 	size_t i;
 	
-	g_return_val_if_fail (num > 0, NULL);
-	
-	if (!(id = g_mime_message_partial_get_id (partials[0])))
+	if (num == 0 || !(id = g_mime_message_partial_get_id (partials[0])))
 		return NULL;
 	
 	/* get them into the correct order... */
 	qsort ((void *) partials, num, sizeof (gpointer), partial_compare);
 	
 	/* only the last message/partial part is REQUIRED to have the total parameter */
-	total = g_mime_message_partial_get_total (partials[num - 1]);
-	if (num != total)
+	if ((total = g_mime_message_partial_get_total (partials[num - 1])) == -1)
+		return NULL;
+	
+	if (num != (size_t) total)
 		return NULL;
 	
 	cat = g_mime_stream_cat_new ();
@@ -346,8 +338,10 @@ g_mime_message_partial_reconstruct_message (GMimeMessagePartial **partials, size
 			goto exception;
 		
 		/* sanity check to make sure we aren't missing any parts */
-		number = g_mime_message_partial_get_number (partial);
-		if (number != i + 1)
+		if ((number = g_mime_message_partial_get_number (partial)) == -1)
+			goto exception;
+		
+		if ((size_t) number != i + 1)
 			goto exception;
 		
 		wrapper = g_mime_part_get_content_object (GMIME_PART (partial));
@@ -421,10 +415,10 @@ g_mime_message_partial_split_message (GMimeMessage *message, size_t max_size, si
 	GMimeDataWrapper *wrapper;
 	const unsigned char *buf;
 	GPtrArray *parts;
-	size_t len, end;
+	gint64 len, end;
 	const char *id;
 	gint64 start;
-	int i;
+	guint i;
 	
 	*nparts = 0;
 	
@@ -460,7 +454,7 @@ g_mime_message_partial_split_message (GMimeMessage *message, size_t max_size, si
 		/* Preferably, we'd split on whole-lines if we can,
 		 * but if that's not possible, split on max size */
 		if ((end = MIN (len, start + max_size)) < len) {
-			register size_t ebx; /* end boundary */
+			register gint64 ebx; /* end boundary */
 			
 			ebx = end;
 			while (ebx > (start + 1) && ebx[buf] != '\n')
