@@ -58,14 +58,7 @@ static void g_mime_multipart_signed_init (GMimeMultipartSigned *mps, GMimeMultip
 static void g_mime_multipart_signed_finalize (GObject *object);
 
 /* GMimeObject class methods */
-static void multipart_signed_prepend_header (GMimeObject *object, const char *header, const char *value);
-static void multipart_signed_append_header (GMimeObject *object, const char *header, const char *value);
-static void multipart_signed_set_header (GMimeObject *object, const char *header, const char *value);
-static const char *multipart_signed_get_header (GMimeObject *object, const char *header);
-static gboolean multipart_signed_remove_header (GMimeObject *object, const char *header);
-static void multipart_signed_set_content_type (GMimeObject *object, GMimeContentType *content_type);
-static char *multipart_signed_get_headers (GMimeObject *object);
-static ssize_t multipart_signed_write_to_stream (GMimeObject *object, GMimeStream *stream);
+static void multipart_signed_encode (GMimeObject *object, GMimeEncodingConstraint constraint);
 
 
 static GMimeMultipartClass *parent_class = NULL;
@@ -106,14 +99,7 @@ g_mime_multipart_signed_class_init (GMimeMultipartSignedClass *klass)
 	
 	gobject_class->finalize = g_mime_multipart_signed_finalize;
 	
-	object_class->prepend_header = multipart_signed_prepend_header;
-	object_class->append_header = multipart_signed_append_header;
-	object_class->remove_header = multipart_signed_remove_header;
-	object_class->set_header = multipart_signed_set_header;
-	object_class->get_header = multipart_signed_get_header;
-	object_class->set_content_type = multipart_signed_set_content_type;
-	object_class->get_headers = multipart_signed_get_headers;
-	object_class->write_to_stream = multipart_signed_write_to_stream;
+	object_class->encode = multipart_signed_encode;
 }
 
 static void
@@ -129,51 +115,10 @@ g_mime_multipart_signed_finalize (GObject *object)
 }
 
 static void
-multipart_signed_prepend_header (GMimeObject *object, const char *header, const char *value)
+multipart_signed_encode (GMimeObject *object, GMimeEncodingConstraint constraint)
 {
-	GMIME_OBJECT_CLASS (parent_class)->prepend_header (object, header, value);
-}
-
-static void
-multipart_signed_append_header (GMimeObject *object, const char *header, const char *value)
-{
-	GMIME_OBJECT_CLASS (parent_class)->append_header (object, header, value);
-}
-
-static void
-multipart_signed_set_header (GMimeObject *object, const char *header, const char *value)
-{
-	GMIME_OBJECT_CLASS (parent_class)->set_header (object, header, value);
-}
-
-static const char *
-multipart_signed_get_header (GMimeObject *object, const char *header)
-{
-	return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
-}
-
-static gboolean
-multipart_signed_remove_header (GMimeObject *object, const char *header)
-{
-	return GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
-}
-
-static void
-multipart_signed_set_content_type (GMimeObject *object, GMimeContentType *content_type)
-{
-	GMIME_OBJECT_CLASS (parent_class)->set_content_type (object, content_type);
-}
-
-static char *
-multipart_signed_get_headers (GMimeObject *object)
-{
-	return GMIME_OBJECT_CLASS (parent_class)->get_headers (object);
-}
-
-static ssize_t
-multipart_signed_write_to_stream (GMimeObject *object, GMimeStream *stream)
-{
-	return GMIME_OBJECT_CLASS (parent_class)->write_to_stream (object, stream);
+	/* Do NOT encode subparts of a multipart/signed */
+	return;
 }
 
 
