@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -24,6 +24,7 @@
 
 #include <glib.h>
 
+#include <gmime/gmime-encodings.h>
 #include <gmime/gmime-object.h>
 
 G_BEGIN_DECLS
@@ -105,6 +106,8 @@ int g_mime_multipart_get_count (GMimeMultipart *multipart);
 void g_mime_multipart_set_boundary (GMimeMultipart *multipart, const char *boundary);
 const char *g_mime_multipart_get_boundary (GMimeMultipart *multipart);
 
+/* convenience functions */
+
 void g_mime_multipart_foreach (GMimeMultipart *multipart, GMimeObjectForeachFunc callback,
 			       gpointer user_data);
 
