@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -27,6 +27,7 @@
 
 #include <gmime/gmime-object.h>
 #include <gmime/gmime-encodings.h>
+#include <gmime/gmime-filter-best.h>
 #include <gmime/gmime-data-wrapper.h>
 
 G_BEGIN_DECLS
@@ -78,7 +79,7 @@ GMimePart *g_mime_part_new_with_type (const char *type, const char *subtype);
 
 /* accessor functions */
 void g_mime_part_set_content_description (GMimePart *mime_part, const char *description);
-const char *g_mime_part_get_content_description (const GMimePart *mime_part);
+const char *g_mime_part_get_content_description (GMimePart *mime_part);
 
 void g_mime_part_set_content_id (GMimePart *mime_part, const char *content_id);
 const char *g_mime_part_get_content_id (GMimePart *mime_part);
@@ -93,11 +94,13 @@ const char *g_mime_part_get_content_location (GMimePart *mime_part);
 void g_mime_part_set_content_encoding (GMimePart *mime_part, GMimeContentEncoding encoding);
 GMimeContentEncoding g_mime_part_get_content_encoding (GMimePart *mime_part);
 
+GMimeContentEncoding g_mime_part_get_best_content_encoding (GMimePart *mime_part, GMimeEncodingConstraint constraint);
+
 void g_mime_part_set_filename (GMimePart *mime_part, const char *filename);
-const char *g_mime_part_get_filename (const GMimePart *mime_part);
+const char *g_mime_part_get_filename (GMimePart *mime_part);
 
 void g_mime_part_set_content_object (GMimePart *mime_part, GMimeDataWrapper *content);
-GMimeDataWrapper *g_mime_part_get_content_object (const GMimePart *mime_part);
+GMimeDataWrapper *g_mime_part_get_content_object (GMimePart *mime_part);
 
 G_END_DECLS
 
