@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -27,7 +27,6 @@
 
 #include <stdio.h>
 #include <sys/types.h>
-#include <unistd.h>
 #include <stdarg.h>
 
 G_BEGIN_DECLS
@@ -71,15 +70,25 @@ typedef struct {
 } GMimeStreamIOVector;
 
 
+/**
+ * GMimeStream:
+ * @parent_object: parent #GObject
+ * @super_stream: parent stream if this is a substream
+ * @position: the current stream position (aka offset)
+ * @bound_start: start boundary of the stream
+ * @bound_end: end boundary of the stream
+ *
+ * Abstract I/O stream class.
+ **/
 struct _GMimeStream {
 	GObject parent_object;
 	
-	/* Note: these are private fields!! */
+	/* <private> */
 	GMimeStream *super_stream;
 	
-	off_t position;
-	off_t bound_start;
-	off_t bound_end;
+	gint64 position;
+	gint64 bound_start;
+	gint64 bound_end;
 };
 
 struct _GMimeStreamClass {
@@ -91,16 +100,16 @@ struct _GMimeStreamClass {
 	int      (* close)  (GMimeStream *stream);
 	gboolean (* eos)    (GMimeStream *stream);
 	int      (* reset)  (GMimeStream *stream);
-	off_t    (* seek)   (GMimeStream *stream, off_t offset, GMimeSeekWhence whence);
-	off_t    (* tell)   (GMimeStream *stream);
-	ssize_t  (* length) (GMimeStream *stream);
-	GMimeStream * (* substream) (GMimeStream *stream, off_t start, off_t end);
+	gint64   (* seek)   (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence);
+	gint64   (* tell)   (GMimeStream *stream);
+	gint64   (* length) (GMimeStream *stream);
+	GMimeStream * (* substream) (GMimeStream *stream, gint64 start, gint64 end);
 };
 
 
 GType g_mime_stream_get_type (void);
 
-void g_mime_stream_construct (GMimeStream *stream, off_t start, off_t end);
+void g_mime_stream_construct (GMimeStream *stream, gint64 start, gint64 end);
 
 
 /* public methods */
@@ -110,26 +119,20 @@ int       g_mime_stream_flush   (GMimeStream *stream);
 int       g_mime_stream_close   (GMimeStream *stream);
 gboolean  g_mime_stream_eos     (GMimeStream *stream);
 int       g_mime_stream_reset   (GMimeStream *stream);
-off_t     g_mime_stream_seek    (GMimeStream *stream, off_t offset, GMimeSeekWhence whence);
-off_t     g_mime_stream_tell    (GMimeStream *stream);
-ssize_t   g_mime_stream_length  (GMimeStream *stream);
+gint64    g_mime_stream_seek    (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence);
+gint64    g_mime_stream_tell    (GMimeStream *stream);
+gint64    g_mime_stream_length  (GMimeStream *stream);
 
-GMimeStream *g_mime_stream_substream (GMimeStream *stream, off_t start, off_t end);
+GMimeStream *g_mime_stream_substream (GMimeStream *stream, gint64 start, gint64 end);
 
-#ifndef GMIME_DISABLE_DEPRECATED
-void      g_mime_stream_ref     (GMimeStream *stream);
-void      g_mime_stream_unref   (GMimeStream *stream);
-#endif
+void      g_mime_stream_set_bounds (GMimeStream *stream, gint64 start, gint64 end);
 
-void      g_mime_stream_set_bounds (GMimeStream *stream, off_t start, off_t end);
-
-ssize_t   g_mime_stream_write_string (GMimeStream *stream, const char *string);
+ssize_t   g_mime_stream_write_string (GMimeStream *stream, const char *str);
 ssize_t   g_mime_stream_printf       (GMimeStream *stream, const char *fmt, ...) G_GNUC_PRINTF (2, 3);
 
 ssize_t   g_mime_stream_write_to_stream (GMimeStream *src, GMimeStream *dest);
 
-
-ssize_t    g_mime_stream_writev (GMimeStream *stream, GMimeStreamIOVector *vector, size_t count);
+ssize_t   g_mime_stream_writev (GMimeStream *stream, GMimeStreamIOVector *vector, size_t count);
 
 G_END_DECLS
 
